/*
 * Copyright (C) 2015-2016 Canonical Ltd.
 *
 * This file is part of Lomiri Weather App
 *
 * Lomiri Weather App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * Lomiri Weather App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import Lomiri.Components 1.3
import "../../components"
import "../../data/keys.js" as Keys

Item {
    id: dataProviderPage
    height: dataSettingsColumn.height

    ListModel {
        id: dataProviderModel
        function initialize() {
            // TRANSLATORS: name of the weather data service provider, only translate if needed
            dataProviderModel.append({"text": i18n.tr("OpenWeatherMap"), "value": "openweathermap"})
        }
    }

    Component.onCompleted: {
        /*
        The Component.onCompleted of the OptionSelector finishes BEFORE
        the onCompleted events of the delegates or the model.
        That is why the initialize() needs to be called here rather than
        in the Component.onCompleted of the ListModel.
        */
        dataProviderModel.initialize()
        for (var i = 0; i < dataProviderModel.count; ++i) {
            if (dataProviderModel.get(i).value === settings.service) {
                dataProviderSetting.selectedIndex = i
                return
            }
        }
        dataProviderSetting.selectedIndex = 0  // in case no match is found due to broken settings
    }

    Column {
        id: dataSettingsColumn
        spacing: units.gu(2)
        height: childrenRect.height
        width: parent.width
        OptionSelector {
            id: dataProviderSetting
            text: i18n.tr("Data Provider")
            model: dataProviderModel
            containerHeight: itemHeight * dataProviderModel.count
            delegate: OptionSelectorDelegate {
                text: model.text
                height: units.gu(4)
            }
            onDelegateClicked: {
                settings.service = model.get(index).value
                refreshData(true);
            }
        }

        Row {
            // anchors.horizontalCenter: parent.horizontalCenter
            visible: !settings.owmAPIkey
            spacing: units.gu(1)
            height: units.gu(4)
            width: parent.width
            TextField {
                id: apiKeyInput
                width: parent.width - units.gu(13) // 3 units for the icon width, 2 unit for the spacing
                placeholderText: i18n.tr("Enter API key")
                hasClearButton: true
                inputMethodHints: Qt.ImhNoPredictiveText | Qt.ImhNoAutoUppercase
                echoMode: TextInput.Password
                onTextChanged: {
                    if (apiKeyInput.length == 32) {
                        applyButton.enabled = true
                    } else {
                        applyButton.enabled = false
                    }
                }
            }
            Icon {
                id: showPassword
                anchors.verticalCenter: parent.verticalCenter
                width: units.gu(3)
                height: width
                name: apiKeyInput.echoMode == TextInput.Password ? "view-on" : "view-off"
                MouseArea {
                    anchors.fill: parent
                    onClicked: apiKeyInput.echoMode == TextInput.Password ? apiKeyInput.echoMode = TextInput.Normal : apiKeyInput.echoMode = TextInput.Password
                }
            }
            Button {
                id: applyButton
                enabled: false
                width: units.gu(8)
                text: i18n.tr("Apply")
                onClicked: settings.owmAPIkey = apiKeyInput.text
            }
        }
        Button {
            id: clearApiKeyButton
            visible: settings.owmAPIkey
            text: i18n.tr("Clear API key")
            onClicked: settings.owmAPIkey = ""
        }
    }
    // Component.onCompleted: {
    //     // If the key file for TWC is not blank, add the service to the model
    //     if (!!Keys.twcKey) {
    //         dataProviderModel.append({ text: "The Weather Channel" })
    //     }
    // }
}
